==> config-api-0.4.0-sources.jar: org/wildfly/swarm/config/management/access/syslog_handler/protocol/ClientCertificateStoreAuthentication.java <==
package org.wildfly.swarm.config.management.access.syslog_handler.protocol;

import org.wildfly.swarm.config.runtime.Address;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * Configuration for the keystore containing the client certificate if the
 * syslog server requires authentication.
 */
@Address("/core-service=management/access=audit/syslog-handler=*/protocol=tls/authentication=client-certificate-store")
@ResourceType("authentication")
@Implicit
public class ClientCertificateStoreAuthentication<T extends ClientCertificateStoreAuthentication<T>> {

	private String key;
	private PropertyChangeSupport pcs;
	private String keyPassword;
	private String keystorePassword;
	private String keystorePath;
	private String keystoreRelativeTo;

	public ClientCertificateStoreAuthentication() {
		this.key = "client-certificate-store";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The password for the keystore key.
	 */
	@ModelNodeBinding(detypedName = "key-password")
	public String keyPassword() {
		return this.keyPassword;
	}

	/**
	 * The password for the keystore key.
	 */
	@SuppressWarnings("unchecked")
	public T keyPassword(String value) {
		Object oldValue = this.keyPassword;
		this.keyPassword = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keyPassword", oldValue, value);
		return (T) this;
	}

	/**
	 * The password for the keystore.
	 */
	@ModelNodeBinding(detypedName = "keystore-password")
	public String keystorePassword() {
		return this.keystorePassword;
	}

	/**
	 * The password for the keystore.
	 */
	@SuppressWarnings("unchecked")
	public T keystorePassword(String value) {
		Object oldValue = this.keystorePassword;
		this.keystorePassword = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystorePassword", oldValue, value);
		return (T) this;
	}

	/**
	 * =The path of the keystore.
	 */
	@ModelNodeBinding(detypedName = "keystore-path")
	public String keystorePath() {
		return this.keystorePath;
	}

	/**
	 * =The path of the keystore.
	 */
	@SuppressWarnings("unchecked")
	public T keystorePath(String value) {
		Object oldValue = this.keystorePath;
		this.keystorePath = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystorePath", oldValue, value);
		return (T) this;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'keystore-relative-to' is provided, the
	 * value of the 'keystore-path' attribute is treated as relative to the path
	 * specified by this attribute.
	 */
	@ModelNodeBinding(detypedName = "keystore-relative-to")
	public String keystoreRelativeTo() {
		return this.keystoreRelativeTo;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'keystore-relative-to' is provided, the
	 * value of the 'keystore-path' attribute is treated as relative to the path
	 * specified by this attribute.
	 */
	@SuppressWarnings("unchecked")
	public T keystoreRelativeTo(String value) {
		Object oldValue = this.keystoreRelativeTo;
		this.keystoreRelativeTo = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystoreRelativeTo", oldValue, value);
		return (T) this;
	}
}

==> config-api-0.4.2-sources.jar: org/wildfly/swarm/config/management/access/syslog_handler/protocol/ClientCertificateStoreAuthentication.java <==
package org.wildfly.swarm.config.management.access.syslog_handler.protocol;

import org.wildfly.swarm.config.runtime.Address;
import java.util.HashMap;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.Implicit;
import java.beans.PropertyChangeSupport;
import java.beans.PropertyChangeListener;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
/**
 * Configuration for the keystore containing the client certificate if the
 * syslog server requires authentication.
 */
@Address("/core-service=management/access=audit/syslog-handler=*/protocol=tls/authentication=client-certificate-store")
@ResourceType("authentication")
@Implicit
public class ClientCertificateStoreAuthentication<T extends ClientCertificateStoreAuthentication<T>>
		extends
			HashMap {

	private String key;
	private PropertyChangeSupport pcs;
	private String keyPassword;
	private String keystorePassword;
	private String keystorePath;
	private String keystoreRelativeTo;

	public ClientCertificateStoreAuthentication() {
		super();
		this.key = "client-certificate-store";
		this.pcs = new PropertyChangeSupport(this);
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * Adds a property change listener
	 */
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		if (null == this.pcs)
			this.pcs = new PropertyChangeSupport(this);
		this.pcs.addPropertyChangeListener(listener);
	}

	/**
	 * Removes a property change listener
	 */
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		if (this.pcs != null)
			this.pcs.removePropertyChangeListener(listener);
	}

	/**
	 * The password for the keystore key.
	 */
	@ModelNodeBinding(detypedName = "key-password")
	public String keyPassword() {
		return this.keyPassword;
	}

	/**
	 * The password for the keystore key.
	 */
	@SuppressWarnings("unchecked")
	public T keyPassword(String value) {
		Object oldValue = this.keyPassword;
		this.keyPassword = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keyPassword", oldValue, value);
		return (T) this;
	}

	/**
	 * The password for the keystore.
	 */
	@ModelNodeBinding(detypedName = "keystore-password")
	public String keystorePassword() {
		return this.keystorePassword;
	}

	/**
	 * The password for the keystore.
	 */
	@SuppressWarnings("unchecked")
	public T keystorePassword(String value) {
		Object oldValue = this.keystorePassword;
		this.keystorePassword = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystorePassword", oldValue, value);
		return (T) this;
	}

	/**
	 * =The path of the keystore.
	 */
	@ModelNodeBinding(detypedName = "keystore-path")
	public String keystorePath() {
		return this.keystorePath;
	}

	/**
	 * =The path of the keystore.
	 */
	@SuppressWarnings("unchecked")
	public T keystorePath(String value) {
		Object oldValue = this.keystorePath;
		this.keystorePath = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystorePath", oldValue, value);
		return (T) this;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'keystore-relative-to' is provided, the
	 * value of the 'keystore-path' attribute is treated as relative to the path
	 * specified by this attribute.
	 */
	@ModelNodeBinding(detypedName = "keystore-relative-to")
	public String keystoreRelativeTo() {
		return this.keystoreRelativeTo;
	}

	/**
	 * The name of another previously named path, or of one of the standard
	 * paths provided by the system. If 'keystore-relative-to' is provided, the
	 * value of the 'keystore-path' attribute is treated as relative to the path
	 * specified by this attribute.
	 */
	@SuppressWarnings("unchecked")
	public T keystoreRelativeTo(String value) {
		Object oldValue = this.keystoreRelativeTo;
		this.keystoreRelativeTo = value;
		if (this.pcs != null)
			this.pcs.firePropertyChange("keystoreRelativeTo", oldValue, value);
		return (T) this;
	}
}
